[xiph-commits] r3343 - in libfishsound/branches/1.0-stable: . include/fishsound

conrad at svn.annodex.net conrad at svn.annodex.net
Fri Jan 11 18:48:19 PST 2008


Author: conrad
Date: 2008-01-11 18:48:16 -0800 (Fri, 11 Jan 2008)
New Revision: 3343

Modified:
   libfishsound/branches/1.0-stable/AUTHORS
   libfishsound/branches/1.0-stable/README
   libfishsound/branches/1.0-stable/configure.ac
   libfishsound/branches/1.0-stable/include/fishsound/constants.h
   libfishsound/branches/1.0-stable/include/fishsound/fishsound.h
Log:
update documentation to mention FLAC support throughout


Modified: libfishsound/branches/1.0-stable/AUTHORS
===================================================================
--- libfishsound/branches/1.0-stable/AUTHORS	2008-01-12 02:27:44 UTC (rev 3342)
+++ libfishsound/branches/1.0-stable/AUTHORS	2008-01-12 02:48:16 UTC (rev 3343)
@@ -1,9 +1,12 @@
 Conrad Parker <conrad at metadecks.org>
         - Design, implementation.
+	- Vorbis, Speex support
+
+Tobias Gehrig
+	- FLAC support
   
-Silvia Pfeiffer <Silvia.Pfeiffer at CSIRO.AU>
+Silvia Pfeiffer <silvia at annodex.net>
         - MS Windows porting, general packaging.
-  
 
 Zentaro Kavanagh <ogg at illiminable.com>
 	- Windows porting and packaging.
@@ -11,8 +14,9 @@
 
 based on code from:
 
-libvorbis, by Monty <monty at xiph.org> and the rest of
-the Xiph.org Foundation.
+libvorbis, by Monty <monty at xiph.org>, Xiph.org Foundation.
 
-libspeex, by Jean-Marc Valin <jean-marc.valin at hermes.usherb.ca>
-and various contributors.
+libspeex, by Jean-Marc Valin <jean-marc.valin at hermes.usherb.ca>,
+Xiph.Org Foundation
+
+libFLAC, by Josh Coalson, Xiph.Org Foundation.

Modified: libfishsound/branches/1.0-stable/README
===================================================================
--- libfishsound/branches/1.0-stable/README	2008-01-12 02:27:44 UTC (rev 3342)
+++ libfishsound/branches/1.0-stable/README	2008-01-12 02:48:16 UTC (rev 3343)
@@ -8,12 +8,12 @@
   http://www.annodex.net/software/libfishsound/
 
 libfishsound provides a simple programming interface for decoding and
-encoding audio data using Xiph.Org codecs (Vorbis and Speex).
+encoding audio data using Xiph.Org codecs (FLAC, Speex and Vorbis).
 
 libfishsound by itself is designed to handle raw codec streams from a
 lower level layer such as UDP datagrams. When these codecs are used in
-files, they are commonly encapsulated in Ogg to produce Ogg Vorbis
-and Speex files.
+files, they are commonly encapsulated in Ogg to produce Ogg FLAC, Speex
+and Ogg Vorbis files.
 
 This source tarball
 -------------------

Modified: libfishsound/branches/1.0-stable/configure.ac
===================================================================
--- libfishsound/branches/1.0-stable/configure.ac	2008-01-12 02:27:44 UTC (rev 3342)
+++ libfishsound/branches/1.0-stable/configure.ac	2008-01-12 02:48:16 UTC (rev 3343)
@@ -478,9 +478,9 @@
 
   Library configuration (./src/libfishsound):
 
+    FLAC support: ................ $FLAC_SUPPORT
+    Speex support: ............... $SPEEX_SUPPORT
     Vorbis support: .............. $VORBIS_SUPPORT
-    Speex support: ............... $SPEEX_SUPPORT
-    Flac support: ................ $FLAC_SUPPORT
 
   Example programs (./src/examples):
 

Modified: libfishsound/branches/1.0-stable/include/fishsound/constants.h
===================================================================
--- libfishsound/branches/1.0-stable/include/fishsound/constants.h	2008-01-12 02:27:44 UTC (rev 3342)
+++ libfishsound/branches/1.0-stable/include/fishsound/constants.h	2008-01-12 02:48:16 UTC (rev 3343)
@@ -82,10 +82,10 @@
   FISH_SOUND_GET_INFO                   = 0x1000,
 
   /** Query if multichannel audio should be interpreted as interleaved */
-  FISH_SOUND_GET_INTERLEAVE      = 0x2000,
+  FISH_SOUND_GET_INTERLEAVE             = 0x2000,
 
   /** Set to 1 to interleave, 0 to non-interleave */
-  FISH_SOUND_SET_INTERLEAVE      = 0x2001,
+  FISH_SOUND_SET_INTERLEAVE             = 0x2001,
 
   FISH_SOUND_SET_ENCODE_VBR             = 0x4000,
   

Modified: libfishsound/branches/1.0-stable/include/fishsound/fishsound.h
===================================================================
--- libfishsound/branches/1.0-stable/include/fishsound/fishsound.h	2008-01-12 02:27:44 UTC (rev 3342)
+++ libfishsound/branches/1.0-stable/include/fishsound/fishsound.h	2008-01-12 02:48:16 UTC (rev 3343)
@@ -41,13 +41,13 @@
  *
  * This is the documentation for the FishSound C API. FishSound provides
  * a simple programming interface for decoding and encoding audio data
  * using Xiph.Org codecs (Vorbis and Speex).
  *
  * libfishsound by itself is designed to handle raw codec streams from
  * a lower level layer such as UDP datagrams.
  * When these codecs are used in files, they are commonly encapsulated in
  * <a href="http://www.xiph.org/ogg/">Ogg</a> to produce
- * <em>Ogg Vorbis</em> and <em>Speex</em> files.
+ * <em>Ogg FLAC</em>, <em>Speex</em> and <em>Ogg Vorbis</em> files.
  * Example C programs using
  * <a href="http://www.annodex.net/software/liboggz/">liboggz</a> to
  * read and write these files are provided in the libfishsound sources.
@@ -68,11 +68,11 @@
  *
  * - \link decode Decoding audio data \endlink:
  * How to decode audio data with FishSound, including source for a fully
  * working Ogg Vorbis and Ogg Speex decoder.
  *
  * - \link encode Encoding audio data \endlink:
  * How to encode audio data with FishSound, including source for a fully
  * working Ogg Vorbis and Ogg Speex encoder.
  *
  * - \link configuration Configuration \endlink:
  * Customizing libfishsound to only decode or encode,
@@ -103,7 +103,7 @@
  * a lower level layer such as UDP datagrams.
  * When these codecs are used in files, they are commonly encapsulated in
  * <a href="http://www.xiph.org/ogg/">Ogg</a> to produce
- * <em>Ogg Vorbis</em> and <em>Speex</em> files.
+ * <em>Ogg FLAC</em>, <em>Speex</em> and <em>Ogg Vorbis</em> files.
  * Example C programs using
  * <a href="http://www.annodex.net/software/liboggz/">liboggz</a> to
  * read and write these files are provided in the libfishsound sources.
@@ -196,13 +196,13 @@
  * - Any attempt to call fish_sound_decode() will return 
  *   FISH_SOUND_ERR_DISABLED
  *
  * \subsection no_vorbis Removing Vorbis support
  *
  * Configuring with \a --disable-vorbis will remove all support for Vorbis:
  * - All internal Vorbis related functions will not be built
  * - Any attempt to call fish_sound_new() with \a mode == FISH_SOUND_ENCODE
  *   and \a fsinfo->format == FISH_SOUND_VORBIS will fail, returning NULL
  * - The resulting library will not be linked against libvorbis or libvorbisenc
  *
  * \subsection no_speex Removing Speex support
  *
@@ -212,12 +212,20 @@
  *   and \a fsinfo->format == FISH_SOUND_SPEEX will fail, returning NULL
  * - The resulting library will not be linked against libspeex
  *
+ * \subsection no_vorbis Removing Vorbis support
+ *
+ * Configuring with \a --disable-vorbis will remove all support for Vorbis:
+ * - All internal Vorbis related functions will not be built
+ * - Any attempt to call fish_sound_new() with \a mode == FISH_SOUND_ENCODE
+ *   and \a fsinfo->format == FISH_SOUND_VORBIS will fail, returning NULL
+ * - The resulting library will not be linked against libvorbis or libvorbisenc
+ *
  * \subsection summary Configuration summary
  * 
  * Upon successful configuration, you should see something like this:
 <pre>
 ------------------------------------------------------------------------
-  libfishsound 0.6.0:  Automatic configuration OK.
+  libfishsound 0.9.0:  Automatic configuration OK.
 
   General configuration:
 
@@ -227,12 +235,13 @@
 
   Library configuration (./src/libfishsound):
 
+    FLAC support: ................ yes
+    Speex support: ............... yes (1.1.x)
     Vorbis support: .............. yes
-    Speex support: ............... yes
 
   Example programs (./src/examples):
 
-    identify decode encode
+    fishsound-identify fishsound-decode fishsound-encode
 
   Installation paths:
 
@@ -240,6 +249,14 @@
     C header files: .............. /usr/local/include/fishsound
     Documentation: ............... /usr/local/share/doc/libfishsound
 
+  Building:
+
+    Type 'make' to compile libfishsound.
+
+    Type 'make install' to install libfishsound.
+
+    Type 'make check' to run test suite (Valgrind testing not enabled)
+
   Example programs will be built but not installed.
 ------------------------------------------------------------------------
 </pre>
@@ -274,6 +291,8 @@
    AC_SUBST(FISHSOUND_LIBS)
  fi
  </pre>
+ * (Note that if your application requires FLAC support, you should check
+ * for a version of fishsound >= 0.9.0).
  *
  * If libfishsound is found, HAVE_FISHSOUND will be set to "yes", and
  * the autoconf variables FISHSOUND_CFLAGS and FISHSOUND_LIBS will
@@ -307,15 +326,15 @@
  *
  * libfishsound provides callback based decoding: you feed it encoded audio
  * data, and it will call your callback with decoded PCM. A more detailed
  * explanation and a full example of decoding Ogg Vorbis and Speex files is
  * provided in the \link decode Decoding audio data \endlink section.
  *
  * \section encoding Encoding
  *
  * libfishsound provides callback based encoding: you feed it PCM audio,
  * and it will call your callback with encoded audio data. A more detailed
  * explanation and a full example of encoding Ogg Vorbis and Speex files is
  * provided in the \link encode Encoding audio data \endlink section.
  */
 
 /** \defgroup decode Decoding audio data
@@ -338,14 +357,14 @@
  * This procedure is illustrated in src/examples/fishsound-decode.c.
  * Note that this example additionally:
  * - uses <a href="http://www.annodex.net/software/liboggz/">liboggz</a> to
  * demultiplex audio data from an Ogg encapsulated Vorbis or Speex stream.
  * Hence, the step of feeding encoded data to libfishsound is done within
  * the OggzReadPacket callback.
  * - uses <a href="http://www.mega-nerd.com/libsndfile/">libsndfile</a> to
  * write the decoded audio to a WAV file.
  *
  * Hence this example code demonstrates all that is needed to decode both
  * Ogg Vorbis and Ogg Speex files:
  *
  * \include fishsound-decode.c
  */
@@ -371,10 +390,10 @@
  * - uses <a href="http://www.mega-nerd.com/libsndfile/">libsndfile</a> to
  * read input from a PCM audio file (WAV, AIFF, etc.)
  * - uses <a href="http://www.annodex.net/software/liboggz/">liboggz</a> to
  * encapsulate the encoded Vorbis or Speex data in an Ogg stream.
  *
  * Hence this example code demonstrates all that is needed to encode
  * Ogg Vorbis and Ogg Speex files:
  *
  * \include fishsound-encode.c
  */
@@ -389,7 +408,7 @@
   /** Count of channels */
   int channels;
 
-  /** FISH_SOUND_VORBIS, FISH_SOUND_SPEEX etc. */
+  /** FISH_SOUND_VORBIS, FISH_SOUND_SPEEX, FISH_SOUND_FLAC etc. */
   int format;
 } FishSoundInfo;
 
@@ -397,7 +416,7 @@
  * Info about a particular sound format
  */
 typedef struct {
-  /** FISH_SOUND_VORBIS, FISH_SOUND_SPEEX etc. */
+  /** FISH_SOUND_VORBIS, FISH_SOUND_SPEEX, FISH_SOUND_FLAC etc. */
   int format;
 
   /** Printable name */
@@ -41,13 +41,13 @@
  * This is the documentation for the FishSound C API. FishSound provides
  * a simple programming interface for decoding and encoding audio data
- * using Xiph.Org codecs (Vorbis and Speex).
+ * using Xiph.Org codecs (FLAC, Speex and Vorbis).
  *
  * libfishsound by itself is designed to handle raw codec streams from
@@ -68,11 +68,11 @@
  * - \link decode Decoding audio data \endlink:
  * How to decode audio data with FishSound, including source for a fully
- * working Ogg Vorbis and Ogg Speex decoder.
+ * working Ogg FLAC, Speex and Ogg Vorbis decoder.
  *
  * - \link encode Encoding audio data \endlink:
@@ -68,11 +68,11 @@
  * - \link encode Encoding audio data \endlink:
  * How to encode audio data with FishSound, including source for a fully
- * working Ogg Vorbis and Ogg Speex encoder.
+ * working Ogg FLAC, Speex and Ogg Vorbis encoder.
  *
  * - \link configuration Configuration \endlink:
@@ -196,13 +196,13 @@
  *   FISH_SOUND_ERR_DISABLED
  *
- * \subsection no_vorbis Removing Vorbis support
+ * \subsection no_flac Removing FLAC support
  *
@@ -196,13 +196,13 @@
  *
- * Configuring with \a --disable-vorbis will remove all support for Vorbis:
- * - All internal Vorbis related functions will not be built
+ * Configuring with \a --disable-flac will remove all support for FLAC:
+ * - All internal FLAC related functions will not be built
  * - Any attempt to call fish_sound_new() with \a mode == FISH_SOUND_ENCODE
@@ -196,13 +196,13 @@
  * - Any attempt to call fish_sound_new() with \a mode == FISH_SOUND_ENCODE
- *   and \a fsinfo->format == FISH_SOUND_VORBIS will fail, returning NULL
- * - The resulting library will not be linked against libvorbis or libvorbisenc
+ *   and \a fsinfo->format == FISH_SOUND_FLAC will fail, returning NULL
+ * - The resulting library will not be linked against libFLAC
  *
  * \subsection no_speex Removing Speex support
@@ -307,15 +326,15 @@
  * libfishsound provides callback based decoding: you feed it encoded audio
  * data, and it will call your callback with decoded PCM. A more detailed
- * explanation and a full example of decoding Ogg Vorbis and Speex files is
- * provided in the \link decode Decoding audio data \endlink section.
+ * explanation and a full example of decoding Ogg FLAC, Speex and Ogg Vorbis
+ * files is provided in the \link decode Decoding audio data \endlink section.
  *
  * \section encoding Encoding
@@ -307,15 +326,15 @@
  * libfishsound provides callback based encoding: you feed it PCM audio,
  * and it will call your callback with encoded audio data. A more detailed
- * explanation and a full example of encoding Ogg Vorbis and Speex files is
- * provided in the \link encode Encoding audio data \endlink section.
+ * explanation and a full example of encoding Ogg FLAC, Speex and Ogg Vorbis
+ * files is provided in the \link encode Encoding audio data \endlink section.
  */
 
@@ -338,14 +357,14 @@
  * Note that this example additionally:
  * - uses <a href="http://www.annodex.net/software/liboggz/">liboggz</a> to
- * demultiplex audio data from an Ogg encapsulated Vorbis or Speex stream.
- * Hence, the step of feeding encoded data to libfishsound is done within
+ * demultiplex audio data from an Ogg encapsulated FLAC, Speex or Vorbis
+ * stream. The step of feeding encoded data to libfishsound is done within
  * the OggzReadPacket callback.
  * - uses <a href="http://www.mega-nerd.com/libsndfile/">libsndfile</a> to
@@ -338,14 +357,14 @@
  * write the decoded audio to a WAV file.
  *
- * Hence this example code demonstrates all that is needed to decode both
- * Ogg Vorbis and Ogg Speex files:
+ * Hence this example code demonstrates all that is needed to decode
+ * Ogg FLAC, Speex or Ogg Vorbis files:
  *
  * \include fishsound-decode.c
@@ -371,10 +390,10 @@
  * read input from a PCM audio file (WAV, AIFF, etc.)
  * - uses <a href="http://www.annodex.net/software/liboggz/">liboggz</a> to
- * encapsulate the encoded Vorbis or Speex data in an Ogg stream.
+ * encapsulate the encoded FLAC, Speex or Vorbis data in an Ogg stream.
  *
  * Hence this example code demonstrates all that is needed to encode
@@ -371,10 +390,10 @@
  *
  * Hence this example code demonstrates all that is needed to encode
- * Ogg Vorbis and Ogg Speex files:
+ * Ogg FLAC, Speex and Ogg Vorbis files:
  *
  * \include fishsound-encode.c



More information about the commits mailing list